
#ifndef CONTACTEDITOR_EXPORT_H
#define CONTACTEDITOR_EXPORT_H

#ifdef CONTACTEDITOR_STATIC_DEFINE
#  define CONTACTEDITOR_EXPORT
#  define CONTACTEDITOR_NO_EXPORT
#else
#  ifndef CONTACTEDITOR_EXPORT
#    ifdef KPim5ContactEditor_EXPORTS
        /* We are building this library */
#      define CONTACTEDITOR_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define CONTACTEDITOR_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef CONTACTEDITOR_NO_EXPORT
#    define CONTACTEDITOR_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef CONTACTEDITOR_DEPRECATED
#  define CONTACTEDITOR_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef CONTACTEDITOR_DEPRECATED_EXPORT
#  define CONTACTEDITOR_DEPRECATED_EXPORT CONTACTEDITOR_EXPORT CONTACTEDITOR_DEPRECATED
#endif

#ifndef CONTACTEDITOR_DEPRECATED_NO_EXPORT
#  define CONTACTEDITOR_DEPRECATED_NO_EXPORT CONTACTEDITOR_NO_EXPORT CONTACTEDITOR_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef CONTACTEDITOR_NO_DEPRECATED
#    define CONTACTEDITOR_NO_DEPRECATED
#  endif
#endif

#endif /* CONTACTEDITOR_EXPORT_H */
